import React, { useState } from 'react';
import { createContext, useContext } from 'react';
import { json, type LoaderFunctionArgs } from '@remix-run/node';
import { authenticator } from '../services/auth.server';
import { IStation, IStationData } from 'app/services/api/interfaces.server';
import { api } from 'app/services/api/json.api.server';
import { useLoaderData } from '@remix-run/react';
import ModalFilter from 'app/coms/modalFilter';
import Station from 'app/coms/ui/Station';
import { Provider } from 'react-redux'
import { store } from 'app/wagonsSlice';
import ModalOperations from 'app/coms/modalOperations';

export async function loader({ request }: LoaderFunctionArgs) {
    const authData = await authenticator.isAuthenticated(request, {
        failureRedirect: '/login',
    });
    const stations: IStation[] = await api.getStations();
    const stationsData = await api.getStationsData();
    const owners: string[] = await api.getOwners();
    const wagonTypeList = await api.getWagonTypes();
    return json({
        stations,
        stationsData,
        owners,
        authData,
        wagonTypeList,
    });
}

export default function Index() {
    const { authData, stations, owners, stationsData, wagonTypeList } =
        useLoaderData<typeof loader>();
    return (
        <div id="index" className='w-full h-full'>
        <div className="flex justify-between">
        <ModalFilter
        db={{
            stationsData: stationsData,
            ownersList: owners,
            wagonTypeList,
        }}
        />
        <ModalOperations />
        </div>
        <div id="control-form" className='w-full h-full flex flex-col rounded-sm border-secondary-200 border-[1px]'>
            <div className="h-9 mb-4 pl-4 bg-secondary-100 text-y-center rounded-t-sm flex items-center">
                АРМ дежурного станции
            </div>
            <div className='py-1 pl-10 pr-4 min-h-[62px] my-[1px] flex gap-[2px] text-center'>
                 <div className="w-12 flex justify-center items-center ">
                    Путь
                </div>
                <div className="w-[76px] flex justify-center items-center ">
                    Всего
                </div>
                <div className="w-12 flex justify-center items-center">
                    Л
                </div>
                <div className="flex grow justify-between items-center px-4 py-1 gap-3" >
                    <span>(Чётная)</span>        
                    <span>Вагоны</span>        
                    <span>(Нечётная)</span>        
                </div>
                <div className="w-12 flex justify-center items-center ">
                    Л
                </div>
                </div>
                <Provider store={store}>
                    {stations.map(station => {
                        const stationData = stationsData.filter(el => el.station.id == station.id);
                        return(<Station stationData={stationData} station={station} key={station.id}/>)
                    })}
                </Provider>
                </div>
    </div>
    );
}
