import fetch from 'node-fetch';
import { env } from 'node:process';
import {
    INorm,
    IOperationType,
    IStation,
    IStationData,
    IUser,
} from './interfaces.server';

const endpoints = {
    getStations: 'stationsList',
    getStationsData: 'stationsData',
    getWagonTypeList: 'wagonTypeList',
    getOwnersList: 'ownersList',
    getNorms: 'operationsTypesNorms',
    getOperationsTypes: 'operationsTypes',
    getUsers:'users'
};

export const api = new (class ApiDB {
    private readonly url = `http://localhost:${(env.DB_PORT ?? 4000).toString()}/`;
    constructor() {}
    async getStations(): Promise<IStation[]> {
        const response = await fetch(this.url + endpoints.getStations, {
            method: 'GET',
        });
        return (await response.json()) as IStation[];
    }
    async getOperationsTypes() {
        const response = await fetch(this.url + endpoints.getOperationsTypes, {
            method: 'GET',
        });
        return (await response.json()) as IOperationType[];
    }
    async getNorms() {
        const response = await fetch(this.url + endpoints.getNorms, {
            method: 'GET',
        });
        return (await response.json()) as INorm[];
    }
    async getWagonTypes() {
        const response = await fetch(this.url + endpoints.getWagonTypeList, {
            method: 'GET',
        });
        return (await response.json()) as string[][];
    }
    async getOwners() {
        const response = await fetch(this.url + endpoints.getOwnersList, {
            method: 'GET',
        });
        return (await response.json()) as string[];
    }

    async getStationData(stationID: number): Promise<IStationData> {
        const response = await fetch(
            this.url + endpoints.getStationsData + `?station.id=${stationID}`,
            {
                method: 'GET',
            },
        );
        return ((await response.json()) as IStationData[])[0];
    }
    async getStationsData(): Promise<IStationData[]> {
        const response = await fetch(this.url + endpoints.getStationsData, {
            method: 'GET',
        });
        return (await response.json()) as IStationData[];
    }
    async getStationsData(): Promise<IStationData[]> {
        const response = await fetch(
            this.url + endpoints.getStationsData,
            {
                method: 'GET',
            },
        );
        return (await response.json()) as IStationData[];
    }
    async getUsers(){
        const response = await fetch(this.url + endpoints.getUsers,{method:"GET"});
        return (await response.json()) as IUser[];
    }
    async createUser(user:Omit<IUser,"id">){
        const response = await fetch(this.url + endpoints.getUsers,{method:"POST",headers:{
            "Content-Type": "application/json",
        },body:JSON.stringify(user)});
        return response.ok
    }
})();
