import { Authenticator } from 'remix-auth';
import { sessionStorage } from './session.server';
import { FormStrategy } from 'remix-auth-form';
import { hash, compare } from 'bcrypt';
import { IUser } from './api/interfaces.server';
import { api } from './api/json.api.server';

export let authenticator = new Authenticator<IUser>(sessionStorage);
const saltRounds = 9;

authenticator.use(
    new FormStrategy(async ({ form }) => {
        let login = <string>form.get('login');
        let password = <string>form.get('password');
        const users = await api.getUsers();
        for (const user of users) {
            if (
                user.login == login &&
                (await compare(password, user.password))
            ) {
                return user;
            }
        }
        throw new Error('Wrong credentials');
    }),
    'user-login',
);

authenticator.use(
    new FormStrategy(async ({ form }) => {
        let login = <string>form.get('login');
        let password = <string>form.get('password');

        let hashedPassword = '';
        hash(password, saltRounds, (error, hash) => {
            if (error) {
                throw error;
            }
            hashedPassword = hash;
        });

        if (!hashedPassword) {
            throw '';
        }

        const user = await api.createUser({ login, password: hashedPassword });

        return user;
    }),
    'user-auth',
);
